@@ -1,18 +1,15 @@
 package Exception::Class::TryCatch;
+
+$VERSION     = "1.10";
+@ISA         = qw (Exporter);
+@EXPORT      = qw ( catch try );
+@EXPORT_OK   = qw ( caught );
+
 use 5.005; # Aiming for same as Exception::Class
 #use warnings -- not supported in Perl 5.5, darn
 use strict;
 use Exception::Class;
-
-BEGIN {
-    use Exporter ();
-    use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = "1.09";
-    @ISA         = qw (Exporter);
-    @EXPORT      = qw ( catch try );
-    @EXPORT_OK   = qw ( caught );
-    %EXPORT_TAGS = ();
-}
+use Exporter ();
 
 my @error_stack;
 
@@ -305,36 +302,29 @@ I<The Perl Journal>, vol. 8, no. 7, pp. 9-13
 
 - L<Exception::Class>
 
-- L<Test::Exception>
-
 - L<Error> [but see (Perrin 2003) before using]
 
-=head1 INSTALLATION
-
-To install this module, type the following:
-
-   perl Build.PL
-   ./Build
-   ./Build test
-   ./Build install
-
 =head1 BUGS
 
-Though this is a simple module, it may contain bugs or have unexpected
-behaviors.
+Please report any bugs or feature using the CPAN Request Tracker.  
+Bugs can be submitted by email to C<bug-DISTNAME@rt.cpan.org> or 
+through the web interface at 
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=DISTNAME>
 
-Please report bugs using the CPAN Request Tracker at
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Exception-Class-TryCatch
+When submitting a bug or request, please include a test-file or a patch to an
+existing test-file that illustrates the bug or desired feature.
 
 =head1 AUTHOR
 
-David A Golden <dagolden@cpan.org>
+David A Golden 
+
+dagolden@cpan.org
 
 http://dagolden.com/
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004, 2005 by David A. Golden
+Copyright (c) 2004, 2005, 2006 by David A. Golden
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
@@ -342,4 +332,27 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
+
 =cut
